
% Original information/source:
  %% FILE: ukthesis.cls
  %% AUTHOR: Erik Stokes
  %% USAGE: To meet the formatting requirements for the University of
  %% Kentucky Graduate school
  %% VERSION: 1.0.0 (July 22, 2008)
  %%-----------------------------------------------------------------
  %% CHANGE LOG:
  %% 4-29-2008
  %% -create nonumbers chapter style (efs)
  %% -modify acknowledgments page so that it appears in the TOC using
  %% the nonumbers chapter style (efs)
  %% -change the way sub(sub)sections are displayed (efs)
  %% 6-10-2008
  %% -add pdf bookmarks for the abstract, dedication and title page (efs)
  %% -remove the indent from the lines on the rules page, making the
  %% margins for that page correct (efs)
  %% -added command \copyrightnotice (efs)
  %% 6-16-2008
  %% -move \@theyear command so that it is defined in every mode (efs)
  %% -redefine \copyrightnotice so the it functions properly when the
  %% pretty option is used (efs)
  %% -add command \copyrightprefix so that the copyright notice can be more
  %% easily customized (efs)
  %% -add names to the signature lines (efs)
  %% -add command \dgs to define the name of the director of graduate
  %% studies (efs)
  %% -add nosignatures option to not display names (for people who are
  %% handing in printed copies (efs)
  %% -changed the toc formating to include the word ``chapater'' (efs)
  %% -the author's thesis got a ``nice formating'' from the graduate
  %% school, so we up the version number to 1.  We're out of beta and
  %% releasing on time
% I got this file from David Moore and have modified it for my own purposes.
% Tyson Van Alfen --- 2019

\def\fileversion{v1.0.0} 
\def\filedate{2008/07/22}

\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{ukthesis}[\filedate\space\fileversion\space UK thesis class]

\newif\if@draft

%use nice formatting instead of the grad schools
\newif\if@pretty\@prettyfalse

%include names on the sig lines
\newif\if@sigs\@sigstrue

\DeclareOption{final}{\@prettyfalse\@sigstrue\PassOptionsToClass{final,oneside,12pt}{memoir}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}
\ExecuteOptions{12pt}
\ProcessOptions\relax

\LoadClass{memoir}

\RequirePackage{calc}

% a command for optional typesetting
\newcommand{\pretty}[1]{}
\if@pretty\renewcommand{\pretty}[1]{#1}\fi

% set the margins
\settrims{0in}{0in}
\setstocksize{11in}{8.5in}
\setlrmarginsandblock{1.5in}{1in}{*}
\setulmarginsandblock{1in}{1in}{*}
\setheaderspaces{*}{\baselineskip}{*}
\newlength{\@extrafootskip}
\settoheight{\@extrafootskip}{1}
\setheadfoot{.5in}{.5in}
\setmarginnotes{10pt}{1in}{1ex}
\checkandfixthelayout

% these lengths control the positioning of title page elements relative to the margins.
% change these if the spec changes.
% abstract page
\newlength{\@abheadskip}\setlength{\@abheadskip}{2.5in}%above abstract
\newlength{\@abheadheight}\setlength{\@abheadheight}{1in}%below abstract
\newlength{\@abdateline}\setlength{\@abdateline}{2in}
\newlength{\@absigline}\setlength{\@absigline}{2.5in}
% approval page
\newlength{\@aptitleskip}\setlength{\@aptitleskip}{3in}%skip this far before the title 
\newlength{\@aptitleheight}\setlength{\@aptitleheight}{1in}%you have this much space for the title 
\newlength{\@apbottomskip}\setlength{\@apbottomskip}{4in} %skip after the signature line 
% cover page
\newlength{\@coverbottomskip}\setlength{\@coverbottomskip}{3in}
\newlength{\@covertopskip}\setlength{\@covertopskip}{3in}
% title page
\newlength{\@titletopskip}\setlength{\@titletopskip}{2.5in}
\newlength{\@titlebottomskip}\setlength{\@titlebottomskip}{2.5in}
\newlength{\@titlelineskip}\setlength{\@titlelineskip}{4in}
\newlength{\@titlelinewidth}\setlength{\@titlelinewidth}{.5\linewidth}
\newlength{\@titletitleheight}\setlength{\@titletitleheight}{\@titlelineskip}
% abstract title page
\newlength{\@abtitlepageabove}\setlength{\@abtitlepageabove}{3in}
\newlength{\@abtitlepagebelow}\setlength{\@abtitlepagebelow}{3in}
% abstract cover page
\newlength{\@abcoverpageabove}\setlength{\@abcoverpageabove}{3in}
\newlength{\@abcoverpagebelow}\setlength{\@abcoverpagebelow}{3in}
% rules page
\newlength{\@rulespageabove}\setlength{\@rulespageabove}{2in}
\newlength{\@rulespagebelow}\setlength{\@rulespagebelow}{1in}



% modify the above lengths to account for the margins
\newlength{\@topmatter}
\newlength{\@bottommatter}\setlength{\@bottommatter}{0in}
\setlength{\@topmatter}{\uppermargin}
\addtolength{\@topmatter}{\headsep}
\addtolength{\@bottommatter}{\lowermargin}
% set lengths for the abstract page
\addtolength{\@abheadskip}{-\@topmatter}
\addtolength{\@absigline}{-\@abdateline}
\addtolength{\@abdateline}{-\@bottommatter}
% set the lengths correctly for the approval page
\addtolength{\@aptitleskip}{-\@topmatter}
\addtolength{\@apbottomskip}{-\@bottommatter}
% lengths for the cover page
\addtolength{\@covertopskip}{-\@topmatter}
\addtolength{\@coverbottomskip}{-\@bottommatter}
% lengths for the title page
\addtolength{\@titletitleheight}{-\@titletopskip}
\addtolength{\@titletopskip}{-\@topmatter}
\addtolength{\@titlebottomskip}{-\@bottommatter}
\addtolength{\@titlebottomskip}{-.75\baselineskip}
% lengths for abstract title page
\addtolength{\@abcoverpageabove}{-\@topmatter}
\addtolength{\@abcoverpagebelow}{-\@bottommatter}

\newlength{\@dedicationskip}\setlength{\@dedicationskip}{4in}
\addtolength{\@dedicationskip}{-\@topmatter}
% lengths for rules page
\addtolength{\@rulespageabove}{-\@topmatter}
\addtolength{\@rulespagebelow}{-\@bottommatter}
% renew \maketitle and related commands
\newcommand{\@theyear}{\number\the\year}%the current year

\newcommand{\@theauthor}{}
\newcommand{\@thetitle}{}
\newcommand{\@theabstract}{}
\newcommand{\@thekeywords}{}
\newcommand{\@thedepartment}{}
\newcommand{\@thecollege}{}
\newcommand{\@theuniversity}{}
\newcommand{\@thelocation}{}
\newcommand{\@theadvisor}{}
\newcommand{\@theadvisorb}{}
\newcommand{\@thedgs}{}

\renewcommand{\author}[1]{
  \renewcommand{\@theauthor}{#1}
}
\renewcommand{\title}[1]{
  \renewcommand{\@thetitle}{#1}
}
\renewcommand{\abstract}[1]{
  \renewcommand{\@theabstract}{#1}
}
\newcommand{\keywords}[1]{
  \renewcommand{\@thekeywords}{#1}
}
\newcommand{\department}[1]{
  \renewcommand{\@thedepartment}{#1}
}
\newcommand{\college}[1]{
  \renewcommand{\@thecollege}{#1}
}
\newcommand{\university}[1]{
  \renewcommand{\@theuniversity}{#1}
}
\newcommand{\location}[1]{
  \renewcommand{\@thelocation}{#1}
}
\newcommand{\advisor}[1]{
  \renewcommand{\@theadvisor}{#1}
}
\newcommand{\advisorb}[1]{
  \renewcommand{\@theadvisorb}{#1}
}
\newcommand{\dgs}[1]{
  \renewcommand{\@thedgs}{#1}
}

% copyright notice
\newcommand{\copyrightnotice}{%
  \par\vfill
  \begin{center}
    Copyright \textcopyright\ \@theauthor, \@theyear.
  \end{center}
}

% title page
\newcommand{\maketitlepage}{
  \setcounter{page}{0}
  \thispagestyle{empty}
  \pdfbookmark[0]{Title Page}{titlepage}
  \begin{center}
    \rule{0in}{\@titletopskip+.75\baselineskip}
    \par\noindent
    \parbox[c][\@titletitleheight][t]{\linewidth}{
      \begin{center}
        \vspace{-.75\baselineskip}
        \@thetitle
      \end{center}
    }
    \par\noindent
    \vspace{\parskip}
    \vspace{-.6\baselineskip} 
    \par\noindent
    \rule{\@titlelinewidth}{1pt}\\
    \vspace{\parskip}
    DISSERTATION\\
    \rule{\@titlelinewidth}{1pt}\\
    \parbox[c][][t]{\@titlelinewidth}{
      \begin{center}
        A dissertation submitted in partial fulfillment of the requirements for the degree of Doctor of Philosophy in the \@thecollege\ at the \\ \@theuniversity
      \end{center}
    }
    \par
    By\\
    \@theauthor \\
    \@thelocation \\
    \vspace{1.5\baselineskip}
    Director: Dr. \@theadvisor, Professor of \@thedepartment \\
    \vspace{1.5\baselineskip}
    \@theyear
    \vfill
    \copyrightnotice
    \vspace{\@titlebottomskip}
  \end{center}
}

% abstract page
\newcommand{\makeabstractpage}{
  \clearpage
  \thispagestyle{empty}
  \pdfbookmark[0]{Abstract}{Abstract}
  \rule{0in}{\@abheadskip+\baselineskip}\newline
  \parbox[c][\@abheadheight][t]{\linewidth}{
    \begin{center}
      \vspace{-.75\baselineskip}
      ABSTRACT OF DISSERTATION
    \end{center}
    }
  \begin{center}
    \vspace{-.75\baselineskip}
    \@thetitle
  \end{center}
  \@theabstract
  \begin{description}
    \item[\textnormal{KEYWORDS:}]\@thekeywords
  \end{description}
  \vfill
  \hspace*{\fill} Author's signature:\underline{\parbox{.3\linewidth}{\if@sigs\hfill\@theauthor\ \hfill
  \else\hfill\fi}}\newline \newline
  \vspace{-.6\baselineskip}
  \par\noindent\vspace{-\baselineskip}
  \hspace*{\fill}
  Date:\underline{\parbox{.3\linewidth}{\if@sigs\hfill\@date\ \hfill \else\hfill\fi}}
  \par
  \rule{0pt}{\@abdateline+\baselineskip}
}

% approval page
\newcommand{\makeapprovalpage}{
  \thispagestyle{empty}
  \rule{0in}{\@aptitleskip+\baselineskip}\newline
  \parbox[c][\@aptitleheight][t]{\linewidth}{
    \begin{center}
      \vspace{-.75\baselineskip}
      \@thetitle
    \end{center}
  }
  \begin{center}
    \vspace{-.75\baselineskip}
    By \\
    \@theauthor
  \end{center}
  \vfill
  \hspace*{\fill} Director of Dissertation:\underline{\parbox{.3\linewidth}{\if@sigs\hfill\@theadvisor\ \hfill\else\hfill\fi}}\newline \newline
  \hspace*{\fill} Director of Graduate Studies:\underline{\parbox{.3\linewidth}{\if@sigs\hfill\@thedgs\ \hfill\else
  \hfill\fi}}\newline \newline
  \hspace*{\fill}
  Date:\underline{\parbox{.3\linewidth}{\if@sigs\hfill\@date \hfill \else\hfill\fi}}
  \par
  \rule{0pt}{\@apbottomskip-4\baselineskip}
}

% environment: acknowledgments
\newenvironment{acknowledgments}{
  \clearpage
  \chapterstyle{nonumbers}
  \chapter[Acknowledgments]{\textnormal{\normalsize{ACKNOWLEDGMENTS}}}
  \thispagestyle{plain}
  \begin{DoubleSpace}
}{
  \end{DoubleSpace}
  \clearpage
}

% environment: dedication
\newenvironment{dedication}{
  \clearpage
  \pdfbookmark[0]{Dedication}{Dedication}
  \thispagestyle{empty}
  \savepagenumber
  \begin{center}
  \rule{0in}{\@dedicationskip}
}{
  \end{center}
  \clearpage
  \restorepagenumber
}

% this gives the grad school required frontmatter
\renewcommand{\maketitle}{
  \begin{titlingpage}
    \maketitlepage
    \makeabstractpage
    \makeapprovalpage
  \end{titlingpage}
  \setcounter{page}{3}
}

%customize list of figures
\renewcommand{\listfigurename}{List of Figures}
\renewcommand{\lofheadstart}{}
\renewcommand{\printloftitle}[1]{\hfill\normalsize{\MakeUppercase{\normalfont{#1}}}\hfill}

%customize list of tables
\renewcommand{\listtablename}{List of Tables}
\renewcommand{\lotheadstart}{}
\renewcommand{\printlottitle}[1]{\hfill\normalsize\MakeUppercase{{\normalfont{#1}}}\hfill}

%customize table of contents
\renewcommand{\contentsname}{Table of Contents}
\renewcommand{\tocheadstart}{}
\renewcommand{\printtoctitle}[1]{\hfill\normalsize\MakeUppercase{{\normalfont{#1}}}\hfill}
\renewcommand{\cftchapterpagefont}{\normalfont}
\renewcommand{\cftchapterfont}{\normalfont}
\renewcommand{\cftpartfont}{\normalfont}
\renewcommand{\cftpartpagefont}{\normalfont}
\renewcommand{\changetocdepth}[0]{0}

% add the word chapter to the toc
\renewcommand{\cftchapterpresnum}{Chapter\ }
\newlength{\toctemp}
\settowidth{\toctemp}{\cftchapterpresnum}
\addtolength{\cftchapternumwidth}{\toctemp} 

% add dots to the chapter lines
\renewcommand{\cftdot}{.}
\renewcommand{\cftchapterleader}{\cftdotfill{\cftsectiondotsep}}
\renewcommand{\cftpartleader}{\cftdotfill{\cftdotsep}}

% setup the header and footer styles
\pagestyle{plain}
\makechapterstyle{small}{
  \renewcommand{\printchaptername}{\normalfont\bfseries Chapter}
  \renewcommand{\chapnumfont}{\normalfont}
  \renewcommand{\chapnamefont}{\normalfont}
  \renewcommand{\printchapternum}{\normalfont\bfseries \thechapter\space}
  \renewcommand{\afterchapternum}{\normalfont}
  \renewcommand{\printchaptertitle}[1]{\normalfont\bfseries ##1}
  \setlength{\beforechapskip}{-\baselineskip}
}

\makechapterstyle{nonumbers}{
  \renewcommand{\printchaptername}{}
  \renewcommand{\chapnumfont}{\normalfont}
  \renewcommand{\chapnamefont}{\normalfont}
  \renewcommand{\printchapternum}{}
  \renewcommand{\afterchapternum}{\normalfont}
  \renewcommand{\printchaptertitle}[1]{\begin{center}##1\end{center}}
  \setlength{\beforechapskip}{-\baselineskip}
}

\chapterstyle{small}
\setsecheadstyle{\bfseries}
\setsubsecheadstyle{\bfseries}
\setsubsubsecheadstyle{\bfseries}
